@@ -1013,9 +1013,9 @@ prepare_list (AppearanceData *data, GtkWidget *list, ThemeType type, GCallback c
   conv_data->thumbnail = thumbnail;
   
   /* set useful data for callbacks */
-  g_object_set_data (G_OBJECT (list), THEME_DATA, conv_data);
+  g_object_set_data_full (G_OBJECT (list), THEME_DATA, conv_data, g_free);
   g_object_set_data (G_OBJECT (list), GSETTINGS_SETTINGS, settings);
-  g_object_set_data (G_OBJECT (list), GSETTINGS_KEY, g_strdup(key));
+  g_object_set_data_full (G_OBJECT (list), GSETTINGS_KEY, g_strdup(key), g_free);
   
   /* select in treeview the theme set in gsettings */
   GtkTreeModel *treemodel;
@@ -1038,6 +1038,7 @@ prepare_list (AppearanceData *data, GtkWidget *list, ThemeType type, GCallback c
   gchar *signal_name = g_strdup_printf("changed::%s", key);
   g_signal_connect (settings, signal_name,
       G_CALLBACK (treeview_gsettings_changed_callback), list);
+  g_signal_connect (settings, signal_name, callback, data);
   g_free (signal_name);
 
   /* connect to treeview change event */
