@@ -628,7 +628,9 @@ static void
 transfer_done_cb (GtkWidget *dialog,
 		  TransferData *tdata)
 {
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	gdk_threads_enter ();
+#endif
 	/* XXX: path should be on the local filesystem by now? */
 
 	if (dialog != NULL) {
@@ -640,7 +642,9 @@ transfer_done_cb (GtkWidget *dialog,
 	g_free (tdata->path);
 	g_free (tdata);
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	gdk_threads_leave ();
+#endif
 }
 
 void
