@@ -22,6 +22,10 @@
 
 #include <gtk/gtk.h>
 
+#if !GTK_CHECK_VERSION(3,0,0)
+#define gtk_widget_get_preferred_size(x,y,z) gtk_widget_size_request(x,y)
+#endif
+
 typedef struct
 {
 	GtkImage *cur_icon;
@@ -82,11 +86,13 @@ nld_search_context_picker_init (NldSearchContextPicker * picker)
 
 #if GTK_CHECK_VERSION (3, 0, 0)
 	separator = gtk_separator_new (GTK_ORIENTATION_VERTICAL);
+	gtk_box_pack_start (GTK_BOX (hbox), separator, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), gtk_image_new_from_icon_name ("pan-down-symbolic", GTK_ICON_SIZE_MENU), FALSE, FALSE, 0);
 #else
 	separator = gtk_vseparator_new ();
-#endif
 	gtk_box_pack_start (GTK_BOX (hbox), separator, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_NONE), FALSE, FALSE, 0);
+#endif
 
 	gtk_widget_show_all (hbox);
 
@@ -115,7 +121,7 @@ menu_position_func (GtkMenu * menu, int *x, int *y, gboolean * push_in, gpointer
 	if (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL)
 	{
 		GtkRequisition req;
-		gtk_widget_size_request (GTK_WIDGET (menu), &req);
+		gtk_widget_get_preferred_size (GTK_WIDGET (menu), &req, NULL);
 		*x += allocation.width - req.width;
 	}
 
